<?php
/**
 * Plugin Name:     Protect Website Content
 * Plugin URI:      https://devkabir.github.io/kk-disable-devtool/
 * Description:     A simple toolkit to disable all the methods that can enter the developer tools to prevent code handling through the developer tools
 * Author:          Dev Kabir
 * Author URI:      https://devkabir.github.io
 * Text Domain:     kk-disable-devtool
 * Version:         1.1.0
 *
 * @package         KK_Disable_Devtool
 */
if (!class_exists('KK_Disable_Devtool'))
{
    final class KK_Disable_Devtool
    {

        const VERSION = '1.1.0';
        const NAME = 'kk-disable-devtool';

        /**
         * KK_Disable_Devtool constructor.
         */
        private function __construct()
        {
            register_activation_hook(__FILE__, [$this, 'activate']);
            add_action('wp_enqueue_scripts', [$this, 'install_scripts'], 10);
            add_action('login_enqueue_scripts', [$this, 'install_scripts'], 10);
            add_action('admin_enqueue_scripts', [$this, 'install_admin_scripts'], 10);
            $this->has_rating_notice();
        }

        /**
         * If an instance exists, this returns it.  If not, it creates one and
         * retuns it.
         *
         * @return KK_Disable_Devtool
         */
        public static function init()
        {
            static $instance = false;

            if (!$instance)
            {
                $instance = new self();
            }

            return $instance;
        }

        /**
         * Update options during plugin activation.
         *
         * @return void
         */
        public function activate()
        {
            $installed = get_option('kk_disable_devtool_installed');
            $later     = get_option('kk_disable_devtool_later');

            if (!$installed)
            {
                update_option('kk_disable_devtool_installed', microtime(true));
            }
            if (!$later)
            {
                update_option('kk_disable_devtool_later', 0);
            }

            update_option('kk_disable_devtool_version', self::VERSION);
        }


        /**
         * Add my scripts to block browser dev tool.
         *
         * @return void
         */
        public function install_scripts()
        {
            wp_enqueue_script(self::NAME, plugin_dir_url(__FILE__) . 'assets/script.min.js', [], self::VERSION, false);
        }

        public function install_admin_scripts()
        {
            wp_enqueue_script(self::NAME, plugin_dir_url(__FILE__) . 'assets/admin.min.js', [], self::VERSION, false);
        }

        private function has_rating_notice()
        {
            $later     = get_option('kk_disable_devtool_later');

            if (false === boolval($later) && intval(human_time_diff(get_option('kk_disable_devtool_installed'), microtime(true))) > 30)
            {
                add_action('admin_notices', [$this, 'show_review_notice']);
                add_action('wp_ajax_kk_disable_devtool_later', [$this, 'hide_review_notice']);
            }
        }

        public function show_review_notice()
        {

            $days = human_time_diff(get_option('kk_disable_devtool_installed'), microtime(true));

?>
            <div class="notice error kk-disable-devtool is-dismissible">
                <p><?php
                    _e('You\'ve been using our plugin for ' . $days . '. Do you want to help us improve our plugin? ', self::VERSION); ?>
                    <?php _e('You are welcome to write a review for us ', self::NAME) ?>
                    <a href="https://wordpress.org/support/plugin/disable-browser-devtool/reviews/#new-post" target="_blank"><?php _e('in this section.', self::NAME) ?></a>
                </p>
            </div>
<?php
        }

        public function hide_review_notice()
        {
            update_option('kk_disable_devtool_later', 1);
        }
    }


    /**
     * Initializes the main plugin
     *
     * @return false|KK_Disable_Devtool
     */
    function kk_disable_devtool()
    {
        return KK_Disable_Devtool::init();
    }

    // kick-off the plugin
    kk_disable_devtool();
}
